% File src/library/base/man/list.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{list}
\alias{list}
\alias{pairlist}
\alias{alist}
\alias{as.list}
\alias{as.list.default}
\alias{as.list.data.frame}
\alias{as.list.environment}
\alias{as.list.factor}
\alias{as.list.function}
\alias{as.pairlist}
\alias{is.list}
\alias{is.pairlist}
\title{Lists -- Generic and Dotted Pairs}
\description{
  二種類の \R リストを作る，強制変換する，そしてチェックする．
}
\usage{
list(\dots)
pairlist(\dots)

as.list(x, \dots)
\method{as.list}{environment}(x, all.names = FALSE, sorted = FALSE, \dots)
as.pairlist(x)

is.list(x)
is.pairlist(x)

alist(\dots)
}
\arguments{
  \item{\dots}{オブジェクト，名前付きかもしれない．}
  \item{x}{強制変換又は検査されるオブジェクト．}
  \item{all.names}{全ての値か，名前の先頭がドットで始まらないものだけ(既定)
    をコピーするかどうかを指示する論理値．}
  \item{sorted}{結果のリストの名前をソート(増加順)するかどうかを
    指示する論理値．これは少々コストがかかるが，環境の比較に対して有益である．}
}
\details{
  \R の殆どのリストは内部的には\emph{総称的ベクトル}である．
  伝統的な\emph{ドット対}リスト(LISP に於けるような)が利用可能であるが
  ユーザーからは滅多に見ることができない
  (関数の \code{\link{formals}} として以外)．

  \code{list} や \code{pairlist} への引数は
  \code{value} もしくは \code{tag = value} の型式を持つ．これらの関数は
  どのように引数が指定されたかに応じて，各値がタグ付き・タグ無しの引数から
  構成されたリストかドット対リストを返す．

  \code{alist} はその引数をそれらが関数引数を記述するかのように
  処理する．従って値は評価されず，値のないタグ付き引数が許される一方，
  \code{list} は単にそれらを無視する．
  \code{alist} は最もしばしば \code{\link{formals}} の関連で使われる．

  \code{as.list} はその引数をリストに変換しようと試みる．
  関数に対してはこれは形式的引数のリストを連結したものと関数本体を返す．
  表現式に対しては構成要素のリストが返される．
  \code{as.list} は総称的であり，既定メソッドは
  非リストに対しては \code{\link{as.vector}(mode = "list")} を
  呼び出す．\code{as.vector} に対するメソッドが使われるかもしれない．
  \code{as.list} は因子を要素が唯ひとつのリストに転換する．
  引数が既にリスト化表現式で無い限り，属性は捨て去られるかもしれない．
  (これは常に属性を捨て去る \code{\link{as.character}} 等とは
  一貫性がなく，リストのコピーは手間がかかるための効率性のためである．)

  \code{is.list} は \code{TRUE} を，その引数が
  \code{list} か \code{length} \eqn{> 0} の \code{pairlist} のとき，そしてその時だけ
  返す．\code{is.pairlist} は \code{TRUE} を，引数が対リストか
  \code{NULL} (下を見よ)の時，そしてその時だけ返す．

  \code{as.list} に対する \code{"\link{environment}"} メソッドは
  名前・値の対を(ドットで始まらない名前に対して)
  環境から名前付きリストに変換する．
  ユーザーは全ての名前付きオブジェクトがコピーされることを要求できる．
  \code{sorted = TRUE} で無い限り，リストは特には順序付けられていない
  (順序はオブジェクトの生成順序と環境がハッシュされているかどうかに依存する)．
  囲み環境は探されない．
  (オブジェクトは複製されるためこれは高価な操作になる可能性がある．)
  リストオブジェクトに対する逆操作 \code{\link{as.environment}()}
  メソッドがある．

  空の対リスト \code{pairlist()} は \code{\link{NULL}} と同じである．
  これは \code{list()} とは異なる．

  \code{as.pairlist} は \code{\link{as.vector}(x, "pairlist")} として
  実装されており，従って総称的関数 \code{as.vector} に対するメソッドを
  選択適用する．リストは要素毎に対リストにコピーされ，
  リストの名前は対リストのタグとして使われる：
  他の型の引数に対する返り値はドキュメント化されていない．

  \code{list}, \code{is.list} そして \code{is.pairlist} は
  プリミティブな関数である．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  空の成分を持つリストの生成は \code{\link{vector}("list", length)}；
  連結には \code{\link{c}}，\code{\link{formals}}．
  \code{\link{unlist}} は近似的に \code{as.list()} の逆．

  プロット注釈中でリストを使うには \sQuote{\link{plotmath}}．
}
\examples{
require(graphics)

# プロット構造を作る
pts <- list(x = cars[,1], y = cars[,2])
plot(pts)

is.pairlist(.Options)  # ユーザーレベルの対リスト

## 長さ5の "予め確保された" 空リスト
vector("list", 5)

# 引数リスト
f <- function() x
# "..." 引数の指定に注意：
formals(f) <- al <- alist(x = , y = 2+3, \dots = )
f
al

## 環境からリストへの変換

e1 <- new.env()
e1$a <- 10
e1$b <- 20
as.list(e1)
}
\keyword{list}
\keyword{manip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/list.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{list}
%\alias{list}
%\alias{pairlist}
%\alias{alist}
%\alias{as.list}
%\alias{as.list.default}
%\alias{as.list.data.frame}
%\alias{as.list.environment}
%\alias{as.list.factor}
%\alias{as.list.function}
%\alias{as.pairlist}
%\alias{is.list}
%\alias{is.pairlist}
%\title{Lists -- Generic and Dotted Pairs}
%\description{
%  Functions to construct, coerce and check for both kinds of \R lists.
%}
%\usage{
%list(\dots)
%pairlist(\dots)
%
%as.list(x, \dots)
%\method{as.list}{environment}(x, all.names = FALSE, sorted = FALSE, \dots)
%as.pairlist(x)
%
%is.list(x)
%is.pairlist(x)
%
%alist(\dots)
%}
%\arguments{
%  \item{\dots}{objects, possibly named.}
%  \item{x}{object to be coerced or tested.}
%  \item{all.names}{a logical indicating whether to copy all values or
%    (default) only those whose names do not begin with a dot.}
%  \item{sorted}{a logical indicating whether the \code{\link{names}} of
%    the resulting list should be sorted (increasingly).  Note that this
%    is somewhat costly, but may be useful for comparison of environments.}
%}
%\details{
%  Almost all lists in \R internally are \emph{Generic Vectors}, whereas
%  traditional \emph{dotted pair} lists (as in LISP) remain available but
%  rarely seen by users (except as \code{\link{formals}} of functions).
%
%  The arguments to \code{list} or \code{pairlist} are of the form
%  \code{value} or \code{tag = value}.  The functions return a list or
%  dotted pair list composed of its arguments with each value either
%  tagged or untagged, depending on how the argument was specified.
%
%  \code{alist} handles its arguments as if they described function
%  arguments.  So the values are not evaluated, and tagged arguments with
%  no value are allowed whereas \code{list} simply ignores them.
%  \code{alist} is most often used in conjunction with \code{\link{formals}}.
%
%  \code{as.list} attempts to coerce its argument to a list.  For
%  functions, this returns the concatenation of the list of formal
%  arguments and the function body.  For expressions, the list of
%  constituent elements is returned.  \code{as.list} is generic, and as
%  the default method calls \code{\link{as.vector}(mode = "list")} for a
%  non-list, methods for \code{as.vector} may be invoked.  \code{as.list}
%  turns a factor into a list of one-element factors.  Attributes may
%  be dropped unless the argument already is a list or expression.  (This
%  is inconsistent with functions such as \code{\link{as.character}}
%  which always drop attributes, and is for efficiency since lists can be
%  expensive to copy.)
%
%  \code{is.list} returns \code{TRUE} if and only if its argument
%  is a \code{list} \emph{or} a \code{pairlist} of \code{length} \eqn{> 0}.
%  \code{is.pairlist} returns \code{TRUE} if and only if the argument
%  is a pairlist or \code{NULL} (see below).
%
%  The \code{"\link{environment}"} method for \code{as.list} copies the
%  name-value pairs (for names not beginning with a dot) from an
%  environment to a named list.  The user can request that all named
%  objects are copied.  Unless \code{sorted = TRUE}, the list is in no
%  particular order (the order
%  depends on the order of creation of objects and whether the
%  environment is hashed).  No enclosing environments are searched.
%  (Objects copied are duplicated so this can be an expensive operation.)
%  Note that there is an inverse operation, the
%  \code{\link{as.environment}()} method for list objects.
%
%  An empty pairlist, \code{pairlist()} is the same as
%  \code{\link{NULL}}.  This is different from \code{list()}.
%
%  \code{as.pairlist} is implemented as \code{\link{as.vector}(x,
%  "pairlist")}, and hence will dispatch methods for the generic function
%  \code{as.vector}.  Lists are copied element-by-element into a pairlist
%  and the names of the list used as tags for the pairlist: the return
%  value for other types of argument is undocumented.
%
%  \code{list}, \code{is.list} and \code{is.pairlist} are
%  \link{primitive} functions.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{vector}("list", length)} for creation of a list with empty
%  components; \code{\link{c}}, for concatenation; \code{\link{formals}}.
%  \code{\link{unlist}} is an approximate inverse to \code{as.list()}.
%
%  \sQuote{\link{plotmath}} for the use of \code{list} in plot annotation.
%}
%\examples{
%require(graphics)
%
%# create a plotting structure
%pts <- list(x = cars[,1], y = cars[,2])
%plot(pts)
%
%is.pairlist(.Options)  # a user-level pairlist
%
%## "pre-allocate" an empty list of length 5
%vector("list", 5)
%
%# Argument lists
%f <- function() x
%# Note the specification of a "..." argument:
%formals(f) <- al <- alist(x = , y = 2+3, \dots = )
%f
%al
%
%## environment->list coercion
%
%e1 <- new.env()
%e1$a <- 10
%e1$b <- 20
%as.list(e1)
%}
%\keyword{list}
%\keyword{manip}
%
\encoding{UTF8}
