% File src/library/base/man/regmatches.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{regmatches}
\alias{regmatches}
\alias{regmatches<-}
\title{Extract or Replace Matched Substrings}
\description{
  \code{\link{regexpr}}, \code{\link{gregexpr}} または
  \code{\link{regexec}} によって得られたマッチされたデータから
  マッチした部分文字列を取り出すまたは取り替える．
}
\usage{
regmatches(x, m, invert = FALSE)
regmatches(x, m, invert = FALSE) <- value
}
\arguments{
  \item{x}{文字列ベクトル．}
  \item{m}{マッチされるデータのオブジェクト．}
  \item{invert}{論理値：もし \code{TRUE} ならマッチしない部分文字列を
    取り出したり置き換える．}
  \item{value}{マッチしたりマッチしなかった部分文字列(\code{詳細}を見よ)
    に対する適当な置き換え値を持つオブジェクト．}
}
\details{
  もし \code{invert} が \code{FALSE} (既定)ならば，\code{regmatches}
  はマッチデータで指定されるようなマッチされた部分文字列を取り出す．
  ベクトルのマッチデータ(\code{\link{regexpr}} で得られるような)に対しては，
  空のマッチは捨て去られる；
  リストのマッチデータに対しては，空のマッチは空の成分
  (長さゼロの文字列ベクトル)を与える．

  もし \code{invert} が \code{TRUE} ならば，\code{regmatches} は
  マッチしなかった部分文字列を取り出す，つまり文字列は
  \code{\link{strsplit}} に似たマッチに従って分割される
  (ベクトルのマッチデータに対しては，最大で一つの分割が行われる)．

  マッチデータは同じ文字数を持つ \code{x} の修正バージョンにマッチされた
  正規表現から得ることが出来ることを注意する．

  置き換え関数はマッチした又はマッチしなかった部分文字列に対して使うことが出来る．
  ベクトルのマッチデータに対しては，もし \code{invert} が \code{FALSE} ならば，
  \code{value} は \code{m} 中のマッチされた要素の数の長さを持つ
  文字列ベクトルでなければならない．さもなければ，それは \code{x} と
  同じ長さを持つ文字列ベクトルのリストで，各々は必要な置き換えの数の
  長さでなければならない．置き換えは値を文字やリストに強制変換し，
  必要なだけ値を気前よくリサイクルする．
  欠損した置き換え値は許されない．
}
\value{
  \code{regmatches} に対しては，もし
  \code{m} がベクトルで \code{invert} が \code{FALSE} ならば
  マッチした部分文字列を持つ文字列ベクトル．
  さもなければマッチした又はマッチしなかった部分文字列を
  持つリスト．

  \code{regmatches<-} に対しては更新された文字列ベクトル．
}
\examples{
x <- c("A and B", "A, B and C", "A, B, C and D", "foobar")
pattern <- "[[:space:]]*(,|and)[[:space:]]"
## regexpr() によるマッチデータ
m <- regexpr(pattern, x)
regmatches(x, m)
regmatches(x, m, invert = TRUE)
## gregexpr() によるマッチデータ
m <- gregexpr(pattern, x)
regmatches(x, m)
regmatches(x, m, invert = TRUE)

## 次を考える
x <- "John (fishing, hunting), Paul (hiking, biking)"
## 人物の間のコンマ(プラス空白)で分割したいが，括弧で囲まれたホビーリスト中のコンマでは
## そうしたくないと仮定する．一つのアイデアは分割に対して使われる部分にマッチするために
## 括弧で囲まれた部分を空白にすることである．そして人物をマッチしなかった部分として取り出す．
## 最初に括弧で囲まれたホビーリストにマッチする．
m <- gregexpr("\\\\([^)]*\\\\)", x)
## 与えられた文字数の空の文字列に対する小さなユーテリティを書く
blanks <- function(n) {
     vapply(Map(rep.int, rep.int(" ", length(n)), n, USE.NAMES = FALSE),
           paste, "", collapse = "")
}
## 括弧部分を空白にした x のコピーを作る．
s <- x
regmatches(s, m) <- Map(blanks, lapply(regmatches(s, m), nchar))
s
## 分割されたマッチの位置を計算する
## (空のマッチデータを持つ x に対して strsplit()
## を呼び出すことは出来ないことを注意する)．
m <- gregexpr(", *", s)
## そして最後にマッチしなかった部分を取り出す．
regmatches(x, m, invert = TRUE)
}
\keyword{character}
\keyword{utilities}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/regmatches.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{regmatches}
%\alias{regmatches}
%\alias{regmatches<-}
%\title{Extract or Replace Matched Substrings}
%\description{
%  Extract or replace matched substrings from match data obtained by
%  \code{\link{regexpr}}, \code{\link{gregexpr}} or
%  \code{\link{regexec}}.
%}
%\usage{
%regmatches(x, m, invert = FALSE)
%regmatches(x, m, invert = FALSE) <- value
%}
%\arguments{
%  \item{x}{a character vector}
%  \item{m}{an object with match data}
%  \item{invert}{a logical: if \code{TRUE}, extract or replace the
%    non-matched substrings.}
%  \item{value}{an object with suitable replacement values for the
%    matched or non-matched substrings (see \code{Details}).}
%}
%\details{
%  If \code{invert} is \code{FALSE} (default), \code{regmatches} extracts
%  the matched substrings as specified by the match data.  For vector
%  match data (as obtained from \code{\link{regexpr}}), empty matches are
%  dropped; for list match data, empty matches give empty components
%  (zero-length character vectors).
%
%  If \code{invert} is \code{TRUE}, \code{regmatches} extracts the
%  non-matched substrings, i.e., the strings are split according to the
%  matches similar to \code{\link{strsplit}} (for vector match data, at
%  most a single split is performed).
%
%  Note that the match data can be obtained from regular expression
%  matching on a modified version of \code{x} with the same numbers of
%  characters.
%
%  The replacement function can be used for replacing the matched or
%  non-matched substrings.  For vector match data, if \code{invert} is
%  \code{FALSE}, \code{value} should be a character vector with length the
%  number of matched elements in \code{m}.  Otherwise, it should be a
%  list of character vectors with the same length as \code{m}, each as
%  long as the number of replacements needed.  Replacement coerces values
%  to character or list and generously recycles values as needed.
%  Missing replacement values are not allowed.
%}
%\value{
%  For \code{regmatches}, a character vector with the matched substrings
%  if \code{m} is a vector and \code{invert} is \code{FALSE}.  Otherwise,
%  a list with the matched or non-matched substrings.
%
%  For \code{regmatches<-}, the updated character vector.
%}
%\examples{
%x <- c("A and B", "A, B and C", "A, B, C and D", "foobar")
%pattern <- "[[:space:]]*(,|and)[[:space:]]"
%## Match data from regexpr()
%m <- regexpr(pattern, x)
%regmatches(x, m)
%regmatches(x, m, invert = TRUE)
%## Match data from gregexpr()
%m <- gregexpr(pattern, x)
%regmatches(x, m)
%regmatches(x, m, invert = TRUE)
%
%## Consider
%x <- "John (fishing, hunting), Paul (hiking, biking)"
%## Suppose we want to split at the comma (plus spaces) between the
%## persons, but not at the commas in the parenthesized hobby lists.
%## One idea is to "blank out" the parenthesized parts to match the
%## parts to be used for splitting, and extract the persons as the
%## non-matched parts.
%## First, match the parenthesized hobby lists.
%m <- gregexpr("\\\\([^)]*\\\\)", x)
%## Write a little utility for creating blank strings with given numbers
%## of characters.
%blanks <- function(n) {
%     vapply(Map(rep.int, rep.int(" ", length(n)), n, USE.NAMES = FALSE),
%           paste, "", collapse = "")
%}
%## Create a copy of x with the parenthesized parts blanked out.
%s <- x
%regmatches(s, m) <- Map(blanks, lapply(regmatches(s, m), nchar))
%s
%## Compute the positions of the split matches (note that we cannot call
%## strsplit() on x with match data from s).
%m <- gregexpr(", *", s)
%## And finally extract the non-matched parts.
%regmatches(x, m, invert = TRUE)
%}
%\keyword{character}
%\keyword{utilities}
%
\encoding{UTF8}
