\name{sigma}
\title{Extract Residual Standard Deviation 'Sigma'}
\alias{sigma}%@%\alias{残差標準偏差を取り出す}
\alias{sigma.default}% lm, nls, glm
\alias{sigma.mlm}
\description{
  エラーの推定標準誤差，
  \dQuote{残差標準誤差}
  (例えば \code{\link{summary.lm}()} の出力のように当てはめモデルの出力中で
  誤って \dQuote{残差標準エラー}と呼ばれる)，を取り出す．

  多くの統計モデルは
  \emph{スケールパラメータ}を持つ．これは典型的に
  平均ゼロの正規(又はガウシアン)確率変数で
  標準偏差は
  \eqn{\sigma} と書かれる．
  \code{sigma(.)} は当てはめモデルから
  \emph{推定}パラメータ，つまり
  \eqn{\hat\sigma}{sigma^} を取り出す．
}
\usage{
sigma(object, ...)

\S3method{sigma}{default}(object, use.fallback = TRUE, ...)
}
\arguments{
  \item{object}{\R オブジェクト，典型的に
    \code{\link{lm}} のようなモデル当てはめ関数の結果．}
  \item{use.fallback}{論理値，\code{\link{nobs}} に渡される．}
  \item{\dots}{
    メソッドへ・から渡される追加引数．
    既定メソッドに対しては \code{\link{deviance}(*, ...)} に渡される．}
}
\details{
 パッケージ \pkg{stats} は S3 総称的関数と既定メソッドを提供する．
 後者は典型的に
 (漸近 / 近似的)一般化ガウシアン
 (\dQuote{最少二乗})問題に対して正しい．なぜならそれは
 \preformatted{%
   sigma.default <- function (object, use.fallback = TRUE, ...)
                      sqrt( deviance(object, ...) / (NN - PP) )
 } と定義されるからである．ここで
 \code{NN <- \link{nobs}(object, use.fallback = use.fallback)}
 そして \code{PP <- length(\link{coef}(object))} である．
}
\value{
  典型的に数値で，ガウシアンモデルに対する
  エラーの推定標準偏差(\dQuote{残差標準偏差}) である．
  そして---より解釈が困難になるが---より一般的なモデルでの
  自由度あたりの残差偏位度の平方根である．
  ある種の一般化線形モデル
  (\code{\link{glm}})の文脈では，
  \eqn{sigma^2} (\code{sigma(.)^2}) は
  \dQuote{散布度(パラメータ)}と呼ばれる．従って，よく当てはめられた二項又は
  ポアッソン GLM に対しては，
  \code{sigma} は約 1 である．

  非常に厳格に言えば，\eqn{\hat{\sigma}}{\sigma^} (\dQuote{\eqn{\sigma} hat})
  は実際には \eqn{\sqrt{\widehat{\sigma^2}}}{\sqrt(hat(\sigma^2))} である．

  多変量線形モデル(クラス \code{"mlm"}) に対してはシグマの
  \emph{ベクトル}が返され，各々は
  \eqn{Y} の一つの列に対応する．
}
\note{
  \dQuote{残差標準\bold{エラー}}という容易に変更できる誤称が
  極めて多くの \R (と S) の出力にある．
}
\seealso{
  \code{\link{deviance}}, \code{\link{nobs}}, \code{\link{vcov}}.
}
\examples{
## -- lm() ------------------------------
lm1 <- lm(Fertility ~ . , data = swiss)
sigma(lm1) # ~= 7.165  summary(lm1) からは "Residual standard error" とプリント
stopifnot(all.equal(sigma(lm1), summary(lm1)$sigma, tol=1e-15))

## -- nls() -----------------------------
DNase1 <- subset(DNase, Run == 1)
fm.DN1 <- nls(density ~ SSlogis(log(conc), Asym, xmid, scal), DNase1)
sigma(fm.DN1) # summary(..) からは ~= 0.01919
stopifnot(all.equal(sigma(fm.DN1), summary(fm.DN1)$sigma, tol=1e-15))

% example from ./predict.glm.R
## -- glm() -----------------------------
## -- a) 二項分布 -- MASS からの例
ldose <- rep(0:5, 2)
numdead <- c(1, 4, 9, 13, 18, 20, 0, 2, 6, 10, 12, 16)
sex <- factor(rep(c("M", "F"), c(6, 6)))
SF <- cbind(numdead, numalive = 20-numdead)
sigma(budworm.lg <- glm(SF ~ sex*ldose, family = binomial))

## -- b) ポアッソン -- ?glm から：
## Dobson (1990) Page 93: Randomized Controlled Trial :
counts <- c(18,17,15,20,10,20,25,13,12)
outcome <- gl(3,1,9)
treatment <- gl(3,3)
sigma(glm.D93 <- glm(counts ~ outcome + treatment, family = poisson()))
## (現在) 次と*異なる*
summary(glm.D93)$dispersion # == 1
## そして *準*ポアッソン散布度
sigma(glm.qD93 <- update(glm.D93, family = quasipoisson()))
sigma (glm.qD93)^2 # 1.282285 は近いが同じではない
summary(glm.qD93)$dispersion # == 1.2933

## -- 多変量 lm() "mlm" -----------
utils::example("SSD", echo=FALSE)
sigma(mlmfit) # 次と同値{しかしより効率的}
sqrt(diag(estVar(mlmfit)))
\dontshow{stopifnot(all.equal(sigma(mlmfit), sqrt(diag(estVar(mlmfit)))))}
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%\name{sigma}
%\title{Extract Residual Standard Deviation 'Sigma'}
%\alias{sigma}
%\alias{sigma.default}% lm, nls, glm
%\alias{sigma.mlm}
%\description{
%  Extract the estimated standard deviation of the errors, the
%  \dQuote{residual standard deviation} (misnomed also
%  \dQuote{residual standard error}, e.g., in
%  \code{\link{summary.lm}()}'s output, from a fitted model).
%
%  Many classical statistical models have a \emph{scale parameter},
%  typically the standard deviation of a zero-mean normal (or Gaussian)
%  random variable which is denoted as \eqn{\sigma}.
%  \code{sigma(.)} extracts the \emph{estimated} parameter from a fitted
%  model, i.e., \eqn{\hat\sigma}{sigma^}.
%}
%\usage{
%sigma(object, ...)
%
%\S3method{sigma}{default}(object, use.fallback = TRUE, ...)
%}
%\arguments{
%  \item{object}{an \R object, typically resulting from a model fitting
%    function such as \code{\link{lm}}.}
%  \item{use.fallback}{logical, passed to \code{\link{nobs}}.}
%  \item{\dots}{potentially further arguments passed to and from
%    methods.  Passed to \code{\link{deviance}(*, ...)} for the default method.}
%}
%\details{
% The \pkg{stats} package provides the S3 generic and a default method.
% The latter is correct typically for (asymptotically / approximately)
% generalized gaussian (\dQuote{least squares}) problems, since it is
% defined as \preformatted{%
%   sigma.default <- function (object, use.fallback = TRUE, ...)
%                      sqrt( deviance(object, ...) / (NN - PP) )
% } where \code{NN <- \link{nobs}(object, use.fallback = use.fallback)}
% and \code{PP <- length(\link{coef}(object))}.
%}
%\value{
%  typically a number, the estimated standard deviation of the
%  errors (\dQuote{residual standard deviation}) for Gaussian
%  models, and---less interpretably---the square root of the residual
%  deviance per degree of freedom in more general models.
%  In some generalized linear modelling (\code{\link{glm}}) contexts,
%  \eqn{sigma^2} (\code{sigma(.)^2}) is called \dQuote{dispersion
%    (parameter)}.  Consequently, for well-fitting binomial or Poisson
%  GLMs, \code{sigma} is around 1.
%
%  Very strictly speaking, \eqn{\hat{\sigma}}{\sigma^} (\dQuote{\eqn{\sigma} hat})
%  is actually \eqn{\sqrt{\widehat{\sigma^2}}}{\sqrt(hat(\sigma^2))}.
%
%  For multivariate linear models (class \code{"mlm"}), a \emph{vector}
%  of sigmas is returned, each corresponding to one column of \eqn{Y}.
%}
%\note{
%  The misnomer \dQuote{Residual standard \bold{error}} has been part of
%  too many \R (and S) outputs to be easily changed there.
%}
%\seealso{
%  \code{\link{deviance}}, \code{\link{nobs}}, \code{\link{vcov}}.
%}
%\examples{
%## -- lm() ------------------------------
%lm1 <- lm(Fertility ~ . , data = swiss)
%sigma(lm1) # ~= 7.165  = "Residual standard error"  printed from summary(lm1)
%stopifnot(all.equal(sigma(lm1), summary(lm1)$sigma, tol=1e-15))
%
%## -- nls() -----------------------------
%DNase1 <- subset(DNase, Run == 1)
%fm.DN1 <- nls(density ~ SSlogis(log(conc), Asym, xmid, scal), DNase1)
%sigma(fm.DN1) # ~= 0.01919  as from summary(..)
%stopifnot(all.equal(sigma(fm.DN1), summary(fm.DN1)$sigma, tol=1e-15))
%
%% example from ./predict.glm.R
%## -- glm() -----------------------------
%## -- a) Binomial -- Example from MASS
%ldose <- rep(0:5, 2)
%numdead <- c(1, 4, 9, 13, 18, 20, 0, 2, 6, 10, 12, 16)
%sex <- factor(rep(c("M", "F"), c(6, 6)))
%SF <- cbind(numdead, numalive = 20-numdead)
%sigma(budworm.lg <- glm(SF ~ sex*ldose, family = binomial))
%
%## -- b) Poisson -- from ?glm :
%## Dobson (1990) Page 93: Randomized Controlled Trial :
%counts <- c(18,17,15,20,10,20,25,13,12)
%outcome <- gl(3,1,9)
%treatment <- gl(3,3)
%sigma(glm.D93 <- glm(counts ~ outcome + treatment, family = poisson()))
%## (currently) *differs* from
%summary(glm.D93)$dispersion # == 1
%## and the *Quasi*poisson's dispersion
%sigma(glm.qD93 <- update(glm.D93, family = quasipoisson()))
%sigma (glm.qD93)^2 # 1.282285 is close, but not the same
%summary(glm.qD93)$dispersion # == 1.2933
%
%## -- Multivariate lm() "mlm" -----------
%utils::example("SSD", echo=FALSE)
%sigma(mlmfit) # is the same as {but more efficient than}
%sqrt(diag(estVar(mlmfit)))
%\dontshow{stopifnot(all.equal(sigma(mlmfit), sqrt(diag(estVar(mlmfit)))))}
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
